AddressConverter class

Link between the AddressInterface and the Address exported from this package

Constructors

AddressConverter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromInterface(AddressInterface addressInterface) Address
convert a AddressInterface to a Address
toInterface(Address address) → AddressInterface
convert a Address to a AddressInterface