AuthTokenConverter class

Link between the AuthTokenInterface and the AuthToken exported from this package

Constructors

AuthTokenConverter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromInterface(AuthTokenInterface authTokenInterface) AuthToken
convert a AuthTokenInterface to a AuthToken
toInterface(AuthToken authToken) → AuthTokenInterface
convert a AuthToken to a AuthTokenInterface