OpenIdUserConverter class

Link between the OpenIdUserInterface and the OpenIdUser exported from this package

Constructors

OpenIdUserConverter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromInterface(OpenIdUserInterface openIdUserInterface) OpenIdUser
convert a OpenIdUserInterface to a OpenIdUser
toInterface(OpenIdUser openIdUser) → OpenIdUserInterface
convert a OpenIdUser to a OpenIdUserInterface