PasswordPolicyException constructor
const
PasswordPolicyException([
- String message = ''
Error thrown when trying to set a password that does not meet the password policy requirements (length, composition or strength)
Implementation
const PasswordPolicyException([super.message = '']);