TooManyAttemptsException constructor

const TooManyAttemptsException([
  1. String message = ''
])

Error thrown when too many attempts are made in a short period of time and the request is blocked by the rate limiter

Implementation

const TooManyAttemptsException([super.message = '']);