PasswordPolicy class
PasswordPolicy class, contains the password policy configured for the ReachFive client (as defined on the Password policy page of the console)
Constructors
- PasswordPolicy({required int minLength, required int minStrength, required bool allowUpdateWithAccessTokenOnly, int? specialCharacters, int? uppercaseCharacters, int? lowercaseCharacters, int? digitCharacters})
-
PasswordPolicy default constructor
const
Properties
- allowUpdateWithAccessTokenOnly → bool
-
Whether the password can be updated with only an access token
(without providing the old password)
final
- digitCharacters → int?
-
The minimum number of digit characters a password must contain,
or
nullif not enforcedfinal - hashCode → int
-
The hash code for this object.
no setterinherited
- lowercaseCharacters → int?
-
The minimum number of lowercase characters a password must contain,
or
nullif not enforcedfinal - minLength → int
-
The minimum number of characters a password must contain
final
- minStrength → int
-
The minimum strength a password must reach (from 0 to 4)
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialCharacters → int?
-
The minimum number of special characters a password must contain,
or
nullif not enforcedfinal - stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - uppercaseCharacters → int?
-
The minimum number of uppercase characters a password must contain,
or
nullif not enforcedfinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited