allowUpdateWithAccessTokenOnly property
Whether the password can be updated with only an access token (without providing the old password)
Implementation
final bool allowUpdateWithAccessTokenOnly;
Whether the password can be updated with only an access token (without providing the old password)
final bool allowUpdateWithAccessTokenOnly;