models/errors library
Exceptions / Errors
- AccountBlockedAfterMultipleLoginAttemptsException
- Error thrown when a user fails to connect too many times
- AccountTemporarilySuspendedException
- Error thrown when a user tries to log in but their account has been temporarily suspended (for example because of a detected usage of leaked credentials)
- EmailAlreadyInUseException
- Error thrown when trying to signup with an already in use email
- InvalidEmailOrPasswordException
- Error thrown when trying to login with an incorrect email or password
- InvalidGrantCodeException
- Error thrown when trying to do an operation with an invalid access token It matches a 401 http error code
- InvalidVerificationCodeException
- Error thrown when trying to update your password with the wrong verification code
- PasswordPolicyException
- Error thrown when trying to set a password that does not meet the password policy requirements (length, composition or strength)
- PasswordTooWeakException
- Error thrown when trying to set a password that is too weak or that has leaked
- SocialAccountEmailAlreadyInUseException
- Error thrown when an user tried to login with a social provider But its email is already in use by another mean of connection
- TooManyAttemptsException
- Error thrown when too many attempts are made in a short period of time and the request is blocked by the rate limiter
- Error thrown when a user tries to refresh its token but it's not authorized anymore (either because it's expired or because it's been revoked for example)
- UpdateSamePasswordException
- Error thrown when trying to update your password with the same password
- UserCancelledOrClosedTheWebFlowCodeException
- Error thrown when an user cancelled or close the web flow